Aussies seal series win in MCG draw | cricket.com.au
Description: Heroics from Johnson, Harris not enough but Australia still regain Border-Gavaskar Trophy

Advertisement

Advertisement

#### MatchReport

30 December 2014

CommBank Test Series v India

# Aussies seal series win in MCG draw

Andrew Ramsey, Melbourne Cricket Ground

- 30 December 2014

- 0

Heroics from Johnson, Harris not enough but Australia still regain Border-Gavaskar Trophy

CommBank Test Series v India, Third Test

AUS

IND

SCORECARD

The series win that brings the Border-Gavaskar Trophy back to Australia after almost two years in India arrived courtesy of a mutually agreed draw rather than the emphatic statement the home team seemed primed to deliver.

When rival captains Steve Smith and MS Dhoni decided no result was possible at 6.24pm this evening, Australia had a further four of their compulsory 15 final-hour overs to bowl and India was nowhere close to their notional victory target of 384 from a minimum 70 overs at 6-174.

While the unassailable two-nil lead that Australia now takes into the last of the four Tests in Sydney next week was undoubtedly a factor in Smith opting to bat through today’s morning session and setting the improbable target, it raised more than a few questions due to its conservatism.

The captain and his brains trust will doubtless argue there was nothing to gain by setting India a goal they might conceivably attain, regardless of the spectacle it might have yielded and the availability of an extra dozen overs or more might have made.

And if the logic for delaying the declaration was to instil in India’s batsmen a sense of futility before the pursuit began, then the incident-laden first half hour of their second innings offered emphatic if ultimately premature vindication.

With his second delivery Ryan Harris did for Shikhar Dhawan whose duck had him briefly being mentioned as a possible omission for next week’s final Commonwealth Bank Test in Sydney.

That was until the man being mooted as his potential replacement – Lokesh Rahul – completed his debut Test with a second innings less meritorious than his forgettable first.

On day three, the highly rated top-order batsman came in at No.6, lasted eight balls from which he was dropped once before holing out to an ugly slog sweep having scored three.

Today, promoted to No.3 in place of out-of-favour and form Cheteshwar Pujara and endured just five deliveries for a single scored before an ambitious pull shot to a ball from Mitchell Johnson that was too full, too close and too fast landed in the hands of Shane Watson running back from slip.

When India’s in-form opener Murali Vijay (11) was pinned lbw to a ball that the video review technology – being used as a novelty rather than a tool in this series – showed would have snuck past leg stump, the tourists were surging towards defeat at 3-19.

And in light of the contribution the bottom half of India’s batting has managed thus far in the series, the end was realistically just one more breakthrough away.

For almost two hours, the Australians searched for it only to fumble when it fell their way.

Kohli should have been run out on four, his anxiety to get his innings underway failing to factor in Australia’s even stronger urge to restrain him as he pushed to mid-off and followed through for a single.

It was only due to a badly-bruised right forearm that David Warner was fielding there rather than his customary spot in the cordon, and it was that same injury that invariably saved Kohli as the return Warner fired after a diving save with Kohli stranded mid-pitch failed to threaten the stumps.

A more straightforward chance was offered by Rahane when he was on 22 and failed to get on top of a cut shot off Johnson that flew above head height to Chris Rogers at point who jumped, clutched and then jogged after the spill which meant his back was turned to the bowler’s displeasure.

In the over prior to tea, Kohli’s impetuosity almost cost him again when he defied old-fashioned cricket wisdom and tried to steal an overthrow that Pujara clearly didn’t believe existed, and was this time spared by Nathan Lyon’s inability to gather the searing throw and break the stumps.

But when the Australians finally secured the wicket they so desperately sought – the in-form, in-your-face Kohli – it came amid such anti-climactic circumstances that the home team couldn’t find it in themselves to give their pantomime villain a send-off.

Perhaps they felt the Indian star was suffering enough, his shock at gently flicking the first ball after tea softly to an equally surprised Joe Burns at square leg reflected in the look he gave the pitch as if he had been done cold by one of those day five grubbers the MCG was once infamous for.

However, the final key that was supposed to unlock India’s dysfunctional lower-order batting took a while to turn.

And when it did, that turn came from an unlikely source.

After shaking Pujara with a bouncer that slammed into the grille of his protective helmet and then another that soared over the batsman’s head, Johnson slipped in the sucker punch in the form of a ‘slow’ (125kph – gentle by his standards) orthodox spinner that would have done Derek Underwood proud.

Delivered from wide with the bowler’s fingers dragged down the side of the ball to impart turn, it pitched on the perfect length to lure Pujara forward and turned sufficiently to beat the bat but not off stump.

Four overs later Harris claimed the other prized scalp when Rahane aimed one of his few false strokes of this Test with a pull that hit high on the bat and looped to midwicket, leaving the Indian tail that had proved so hopelessly inadequate over the past year 15 overs to survive.

But Dhoni and spinner Ravi Ashwin defied both recent history and the Australian attack to survive a final hour and eliminate the prospect of a series whitewash.

The talking point at day’s beginning was at what stage of the morning Smith would shut down his second innings and let his bowlers loose on the tourists.

As it transpired, it was so far into the afternoon the players were on their way to the lunch room beneath the MCC Members’ Stand when the flag was waved, the tourists handed an unappetising order of 384 runs from a minimum of 70 overs to keep the series afloat.

The tardiness of Smith’s declaration had become topical to the point of obsession during a morning session that began 24 minutes early, lost 40 minutes to Melbourne’s traditional festive season drizzle and came within a few centimetres of delivering a highlight.

That came when Shaun Marsh’s three-year wait to score a Test century on home soil was scuttled as he dived to complete his hundredth run, found short by Kohli (of course) who swooped, gathered and hit the stumps from close range as he sensed the Australian’s desperation for the milestone.

A polarising figure due to the vast, unexplained fluctuations between his successes and failures, Marsh is unlikely to finish with a Bradman-esque average.

But given how close he was to completing the run that distinguishes a very good innings from a great one he should perhaps be listed in the scorebook as ‘run out (Kohli) 99.94’.

The mean-spiritedness of declaring on a batsman who has fought a long and public battle to forge an international career just as a definitive moment beckoned was one mitigating reason for Smith opting to bat India out of the series before declaring.

The effect of the damp outfield on his bowlers’ capacity to grip the ball another.

As was the prospect of India taking the second new-ball early in the day, thus raising the hope of a lift in the miserable scoring rate above the barely-two-runs-per-over the seemingly aimless session eventually yielded.

And maybe even the tidal fluctuations of the nearby Yarra River.

Whatever the rationale, Smith was so often and so closely scrutinised by television cameras as he sat in the dressing room casually tossing a ball from hand to hand he could have been excused for thinking he had become a Big Brother inmate.

While the simple explanation – that in holding a two-nil series lead and having been bowled out twice in the first three Tests there was no conceivable reason to gift India the remotest chance of winning – was also the most credible, the morning’s tactics remained curious.

Once the prospect of losing an early wicket and having the tailenders face a new ball had passed, why not up the tempo and grant yourself more than two sessions – albeit extended ones due to poor weather – to seal the series with a win rather than a damp draw?

The opinions expressed here are the views of the writer and do not necessarily reflect the views and opinions of Cricket Australia.

## Filed Under

Australia

India

CommBank Test Series v India

Advertisement

## Top Stories

CommBank Test Series v India

### Johnson an injury worry for Aussies

AAP

- 0

CommBank Test Series v India

### Watson ready for emotional SCG return

Andrew Ramsey

- 2:02
- 0

### Stars soar, Renegades hit record low

- 3h ago
- 0

### Harris backs Siddle return to Test cricket

- 2:02
- 0

### Hodge likely to miss rest of BBL|04

- 1:23
- 0

### Sangakkara fastest to 12,000 Test runs

- 0

Advertisement

## Most Popular

1

### Reed debuts with big crash

2

### Ramdin leads Windies fightback in Cape Town

3

### Hurricanes send off Sammy in style

4

### Johnson an injury worry for Aussies

5

### Bailey sorry for swearing during BBL

Advertisement

Advertisement

Advertisement

##

##